from setuptools import setup, find_packages
  
with open('requirements.txt') as f:
    requirements = f.readlines()
  
long_description = 'Simple CLI tool used for exploring and parsing HTML documents'
  
setup(
        name ='hdistill',
        version ='0.1.2',
        author ='Seth Taylor',
        author_email ='seth.tales@gmail.com',
        url ='https://github.com/SethTales/hdistill',
        description ='CLI tool for parsing HTML',
        long_description = long_description,
        long_description_content_type ="text/markdown",
        license ='MIT',
        packages = find_packages(),
        entry_points ={
            'console_scripts': [
                'hdistill = hdistill.main:main'
            ]
        },
        classifiers =(
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ),
        keywords ='HTML parsing web-scraping',
        install_requires = requirements,
        zip_safe = False
)


from adapters.http_client import HttpClient
from pipeline.html_parser import HtmlParser
from pipeline.sanitizer import Sanitizer
from pipeline.transformer import Transformer

class HDistill():

    def __init__(self, HttpClient, HtmlParser, Sanitizer, Transformer):
        self._http_client = HttpClient
        self._html_parser = HtmlParser
        self._sanitizer = Sanitizer
        self._transformer = Transformer

    def distill(self, url: str, xpath: str) -> []:
        html_content = self._http_client.get_html_content(url)
        parsed = self._html_parser.parse_html(html_content, xpath)
        sanitized = self._sanitizer.sanitize(parsed)
        return self._transformer.transform(sanitized)
